## Groq

Groq is a fast AI inference technology and service, powered by LPU™ AI inference technology which delivers fast, affordable, and energy efficient AI.

Groq provides free access to popular modules and models, usually delivered at much faster speeds than other AI platforms (for the same models).

#### MPVs and Experiments using Groq

 - [Speak in 6x languages      ](docs/platforms/groq/speak-in-6-languages)
 - [Talk with 3x Board Personas](docs/platforms/groq/multiple-board-personas)

#### Supported Models

| **Company** | **Model**                | **Identifier**                          |
|-------------|--------------------------|-----------------------------------------|
| **Meta**    | Llama 3.1 70B            | llama-3.1-70b-versatile                 |
| **Meta**    | Llama 3.1 8B             | llama-3.1-8b-instant                    |
| **Meta**    | LLaMA3 8b                | llama3-8b-8192                          |
| **Meta**    | LLaMA3 70b               | llama3-70b-8192                         |
| **Mistral** | Mixtral 8x7b             | mixtral-8x7b-32768                      |
| **Google**  | Gemma 7b                 | gemma-7b-it                             |
| **Google**  | Gemma2 9b                | gemma2-9b-it                            |
| **Groq**    | LLaMA3 Groq 8b Tool      | llama3-groq-8b-8192-tool-use-preview    |
| **Groq**    | LLaMA3 Groq 70b Tool     | llama3-groq-70b-8192-tool-use-preview   |


----
<img src="https://wow.groq.com/wp-content/uploads/2024/03/PBG-mark1-black.svg" alt="Groq Logo" width="100"/>

